@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * support other XAuth types and possibly DECnet... */
 
 #include <config.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <unistd.h>
@@ -69,10 +69,10 @@ display_add_error (GdmDisplay *d)
 		gdm_error (_("%s: Could not write new authorization entry.  "
 			     "Possibly out of diskspace"),
 			   "add_auth_entry");
-	if (d->console) {
+	if (d->attached) {
 		char *s = g_strdup_printf
-			(_("GDM could not write a new authorization "
-			   "entry to disk.  Possibly out of diskspace.%s%s"),
+			(C_(N_("GDM could not write a new authorization "
+			       "entry to disk.  Possibly out of diskspace.%s%s")),
 			 errno != 0 ? "  Error: " : "",
 			 errno != 0 ? strerror (errno) : "");
 		gdm_text_message_dialog (s);
@@ -581,6 +581,18 @@ gdm_auth_user_add (GdmDisplay *d, uid_t user, const char *homedir)
     if (!d)
 	return FALSE;
 
+    if (d->local_auths != NULL) {
+	    gdm_auth_free_auth_list (d->local_auths);
+	    d->local_auths = NULL;
+    }
+
+    d->local_auths = get_local_auths (d);
+
+    if (d->local_auths == NULL) {
+	    gdm_error ("Can't make cookies");
+	    return FALSE;
+    }
+
     gdm_debug ("gdm_auth_user_add: Adding cookie for %d", user);
 
     /* Determine whether UserAuthDir is specified. Otherwise ~user is used */
@@ -597,18 +609,6 @@ gdm_auth_user_add (GdmDisplay *d, uid_t user, const char *homedir)
 	    authdir = g_strdup (homedir);
     }
 
-    if (d->local_auths != NULL) {
-	    gdm_auth_free_auth_list (d->local_auths);
-	    d->local_auths = NULL;
-    }
-
-    d->local_auths = get_local_auths (d);
-
-    if (d->local_auths == NULL) {
-	    gdm_error ("Can't make cookies");
-	    return FALSE;
-    }
-
 try_user_add_again:
 
     locked = FALSE;
@@ -712,6 +712,8 @@ try_user_add_again:
 	af = gdm_safe_fopen_ap (d->userauth);
     }
 
+    g_free (authdir);
+
     if G_UNLIKELY (af == NULL) {
 	/* Really no need to clean up here - this process is a goner anyway */
 	gdm_error (_("%s: Could not open cookie file %s"),
@@ -729,8 +731,6 @@ try_user_add_again:
 		goto try_user_add_again;
 	}
 
-	g_free (authdir);
-
 	return FALSE; 
     }
 
@@ -788,8 +788,6 @@ try_user_add_again:
     gdm_debug ("gdm_auth_user_add: Done");
 
     umask (022);
-
-    g_free (authdir);
     return ret;
 }
 
@@ -1005,7 +1003,7 @@ gdm_auth_purge (GdmDisplay *d, FILE *af, gboolean remove_when_empty)
     /* Write out remaining entries */
     for (li = keep; li != NULL; li = li->next) {
 	    /* FIXME: is this correct, if we can't open
-	     * this is quite crap isn't it ... */
+	     * this is quite bad isn't it ... */
 	    if G_LIKELY (af != NULL)
 		    XauWriteAuth (af, li->data);
 	            /* FIXME: what about errors? */
