@@ -252,6 +252,7 @@ enum {
 #define GDM_KEY_DISALLOWTCP "security/DisallowTCP=true"
 
 #define GDM_KEY_NEVERPLACECOOKIESONNFS "security/NeverPlaceCookiesOnNFS=true"
+#define GDM_KEY_PASSWORDREQUIRED "security/PasswordRequired=false"
 
 #define GDM_KEY_XDMCP "xdmcp/Enable=false"
 #define GDM_KEY_MAXPEND "xdmcp/MaxPending=4"
@@ -344,7 +345,9 @@ enum {
 #define GDM_KEY_ALLOWADD "chooser/AllowAdd=true"
 
 #define GDM_KEY_DEBUG "debug/Enable=false"
+#define GDM_KEY_DEBUG_GESTURES "debug/Gestures=false"
 
+#define GDM_KEY_SECTION_GREETER "greeter"
 #define GDM_KEY_SECTION_SERVERS "servers"
 
 #define GDM_KEY_SHOW_GNOME_FAILSAFE "greeter/ShowGnomeFailsafeSession=true"
@@ -388,6 +391,10 @@ typedef struct _GdmDisplay GdmDisplay;
 #define GDM_AUTHFILE(display) \
 	(display->authfile_gdm != NULL ? display->authfile_gdm : display->authfile)
 
+#ifdef sun
+#define SDTLOGIN_DIR "/var/dt/sdtlogin"
+#endif
+
 struct _GdmDisplay {
     CARD32 sessionid;
     Display *dsp;
