@@ -704,7 +704,7 @@ connect_to_parent (GdmDisplay *d)
 	}
 
 	if (d->parent_dsp == NULL)
-		gdm_error (_("%s: failed to connect to parent display '\%s\'"),
+		gdm_error (_("%s: failed to connect to parent display \'%s\'"),
 			   "gdm_server_start", d->parent_disp);
 
 	return d->parent_dsp != NULL;
@@ -1288,13 +1288,23 @@ gdm_server_spawn (GdmDisplay *d, const char *vtarg)
 		setgroups (1, groups);
 	}
 
+#if sun
+    {
+        /* Remove old communication pipe, if present */
+        char old_pipe[MAXPATHLEN];
+
+        sprintf (old_pipe, "%s/%d", SDTLOGIN_DIR, d->name);
+        unlink (old_pipe);
+    }
+#endif
+
 	VE_IGNORE_EINTR (execv (argv[0], argv));
 
 	gdm_fdprintf (2, "GDM: Xserver not found: %s\n"
 		      "Error: Command could not be executed!\n"
-		      "Please install the X server or edit %s to point "
-		      "to the right place.",
-		      command, GDM_CONFIG_FILE);
+		      "Please install the X server or correct "
+		      "GDM configuration and restart GDM.",
+		      command);
 
 	gdm_error (_("%s: Xserver not found: %s"), 
 		   "gdm_server_spawn", command);
