@@ -1,20 +1,21 @@
-/*
- *    GDMXnestChooser - run X nest with a chooser using xdmcp
- *    (c)2001 Queen of England
+/* GDM - The GNOME Display Manager
+ * Copyright (c) 2001 Queen of England
  *    
- *    This program is free software; you can redistribute it and/or modify
- *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation; either version 2 of the License, or
- *    (at your option) any later version.
+ * GDMXnestChooser - run X nest with a chooser using xdmcp
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *   
- *    This program is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *   
- *    You should have received a copy of the GNU General Public License
- *    along with this program; if not, write to the Free Software
- *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  * 
  */
 
@@ -39,6 +40,7 @@
 
 #include "gdm.h"
 #include "gdmcomm.h"
+#include "gdmcommon.h"
 
 static pid_t xnest_pid = 0;
 
@@ -467,6 +469,7 @@ main (int argc, char *argv[])
 	const char **args;
 	char *xnest;
 	char **execvec;
+	gchar *config_file, *config_prefix;
 	struct sigaction term;
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
@@ -501,15 +504,25 @@ main (int argc, char *argv[])
 	if (args != NULL && args[0] != NULL)
 		host = args[0];
 
-	gnome_config_push_prefix ("=" GDM_CONFIG_FILE "=/");
+	config_file = gdm_common_get_config_file ();
+	if (config_file == NULL) {
+		g_print (_("Could not access GDM configuration file.\n"));
+		_exit (1);
+	}
+
+	config_prefix = g_strdup_printf("=%s=/", config_file);
+	gnome_config_push_prefix (config_prefix);
 	xdmcp_enabled = gnome_config_get_bool (GDM_KEY_XDMCP);
 	honor_indirect = gnome_config_get_bool (GDM_KEY_INDIRECT);
 	pidfile = gnome_config_get_string (GDM_KEY_PIDFILE);
 	xnest = gnome_config_get_string (GDM_KEY_XNEST);
 	gnome_config_pop_prefix ();
+	g_free (config_file);
+	g_free (config_prefix);
 
 	/* complex and wonderous way to get the exec vector */
 	execvec = make_us_an_exec_vector (xnest);
+	g_free (xnest);
 
 	if (execvec == NULL) {
 		GtkWidget *d;
@@ -517,9 +530,7 @@ main (int argc, char *argv[])
 				       GTK_DIALOG_MODAL /* flags */,
 				       GTK_MESSAGE_ERROR,
 				       GTK_BUTTONS_OK,
-				       FALSE /* markup */,
 				       _("Xnest doesn't exist."),
-				       "%s",
 				       _("Please ask your system "
 					 "administrator "
 					 "to install it."));
@@ -545,13 +556,10 @@ main (int argc, char *argv[])
 				 GTK_DIALOG_MODAL /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
 				 _("Indirect XDMCP is not enabled"),
-				 "%s",
 				 _("Please ask your "
 				   "system administrator to enable "
-				   "it in the GDM configurator "
-				   "program."));
+				   "this feature."));
 			gtk_widget_show_all (d);
 			gtk_dialog_run (GTK_DIALOG (d));
 			gtk_widget_destroy (d);
@@ -566,13 +574,10 @@ main (int argc, char *argv[])
 				 GTK_DIALOG_MODAL /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
 				 _("XDMCP is not enabled"),
-				 "%s",
 				 _("Please ask your "
 				   "system administrator to enable "
-				   "it in the GDM configurator "
-				   "program."));
+				   "this feature."));
 			gtk_widget_show_all (d);
 			gtk_dialog_run (GTK_DIALOG (d));
 			gtk_widget_destroy (d);
@@ -580,8 +585,10 @@ main (int argc, char *argv[])
 		}
 
 		pid = 0;
-		if (pidfile != NULL)
+		if (pidfile != NULL) {
 			VE_IGNORE_EINTR (fp = fopen (pidfile, "r"));
+			g_free (pidfile);
+		}
 		if (fp != NULL) {
 			int r;
 			VE_IGNORE_EINTR (r = fscanf (fp, "%ld", &pid));
@@ -600,9 +607,7 @@ main (int argc, char *argv[])
 				 GTK_DIALOG_MODAL /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
 				 _("GDM is not running"),
-				 "%s",
 				 _("Please ask your "
 				   "system administrator to start it."));
 			gtk_widget_show_all (d);
@@ -619,10 +624,9 @@ main (int argc, char *argv[])
 				       GTK_DIALOG_MODAL /* flags */,
 				       GTK_MESSAGE_ERROR,
 				       GTK_BUTTONS_OK,
-				       FALSE /* markup */,
 				       _("Could not find a free "
 					 "display number"),
-				       /* avoid warning */ "%s", "");
+				       "");
 		gtk_widget_show_all (d);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (d);
